==> haskell-uri-bytestring-0.3.2.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.0
id: uri-bytestring-0.3.2.0-3CEGzHB1AsoAQwzUWUwwUA
key: uri-bytestring-0.3.2.0-3CEGzHB1AsoAQwzUWUwwUA
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: b8b29a660b0f1817c2cf50f3890d0cb6
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/uri-bytestring-0.3.2.0
hs-libraries: HSuri-bytestring-0.3.2.0-3CEGzHB1AsoAQwzUWUwwUA
depends:
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    bytestring-0.10.8.2 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    template-haskell-2.13.0.0
    th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm containers-0.5.11.0
abi-depends: attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm=7dd946a3d778de3bfefccdeba2fc0237
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.2.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uri-bytestring
version: 0.3.2.0
id: uri-bytestring-0.3.2.0-GGXdhiEeYPC9cyAcIp1Hj9
key: uri-bytestring-0.3.2.0-GGXdhiEeYPC9cyAcIp1Hj9
license: BSD-3-Clause
copyright: Soostone Inc.
maintainer: Michael Xavier <michael.xavier@soostone.com>
author: Doug Beardsley, Michael Xavier
homepage: https://github.com/Soostone/uri-bytestring
synopsis: Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.
category: Web
abi: 2007c0ac2d1e568d38112f0f2f55ad0f
exposed: True
exposed-modules:
    URI.ByteString URI.ByteString.QQ
hidden-modules: URI.ByteString.Lens URI.ByteString.Types
                URI.ByteString.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/uri-bytestring-0.3.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/uri-bytestring-0.3.2.0
hs-libraries: HSuri-bytestring-0.3.2.0-GGXdhiEeYPC9cyAcIp1Hj9
depends:
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    bytestring-0.10.8.2 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    template-haskell-2.13.0.0
    th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm containers-0.5.11.0
abi-depends: attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             th-lift-instances-0.1.11-G3GRgWLM0QV6FREef2ZOIm=7dd946a3d778de3bfefccdeba2fc0237
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock
haddock-html: /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
